BoolTagExprSyntaxParse

Trait BoolTagExprSyntaxParse 

pub trait BoolTagExprSyntaxParse<T: BoolTagExprLexicalParse> {
    // Required method
    fn syntax_parse(self) -> Result<BoolTagExpr, ParseError>;
}
Implementing types can be (lexically and) syntactically parsed to a boolean expression tree

Required Methods

fn syntax_parse(self) -> Result<BoolTagExpr, ParseError>

Lexically and then syntactically parse the value into a boolean expression tree

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: BoolTagExprLexicalParse> BoolTagExprSyntaxParse<T> for T

Blanket implementation of syntax parsing for any type that implements BoolTagExprLexicalParse